@@ -5,13 +5,12 @@ use 5.006002;
 use strict;
 use warnings;
 
-use My::Module::Recommend::Any;
-our @ISA = qw{ My::Module::Recommend::Any };
+use base qw{ My::Module::Recommend::Any };
 
 use Carp;
 use Exporter qw{ import };
 
-our $VERSION = '0.133_01';
+our $VERSION = '0.072';
 
 our @EXPORT_OK = qw{ __all };
 
@@ -30,6 +29,7 @@ sub check {
     return @missing;
 }
 
+
 1;
 
 __END__
@@ -90,9 +90,7 @@ modules in scalar context.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-satpass>,
-L<https://github.com/trwyant/perl-Astro-Coord-ECI/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -100,7 +98,7 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2025 by Thomas R. Wyant, III
+Copyright (C) 2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
