@@ -8,12 +8,10 @@ use warnings;
 use Carp;
 use Exporter qw{ import };
 
-our $VERSION = '0.133_01';
+our $VERSION = '0.072';
 
 our @EXPORT_OK = qw{ __any };
 
-use constant ARRAY_REF	=> ref [];
-
 use constant RECOMMEND_TEMPLATE_SINGLE	=> "    * %s is not available.\n";
 use constant RECOMMEND_TEMPLATE_MULTI	=> "    * None of %s is available.\n";
 
@@ -38,7 +36,7 @@ sub new {
 sub check {
     my ( $self ) = @_;
     my @missing;
-    foreach my $m ( @{ $self->{modules} } ) {
+    foreach my $m ( $self->modules() ) {
 	$self->__is_module_available( $m )
 	    and return;
 	push @missing, $m;
@@ -48,7 +46,7 @@ sub check {
 
 sub __is_module_available {
     my ( undef, $m ) = @_;
-    my ( $mod, $ver ) = ARRAY_REF eq ref $m ? @{ $m } : ( $m );
+    my ( $mod, $ver ) = 'ARRAY' eq ref $m ? @{ $m } : ( $m );
     my @eval = ( "require $mod;" );
     defined $ver
 	and push @eval, "$mod->VERSION( $ver );";
@@ -60,13 +58,11 @@ sub __is_module_available {
 sub modules {
     my ( $self ) = @_;
     return (
-	map { ARRAY_REF eq ref $_ ? $_->[0] : $_ }
+	map { 'ARRAY' eq ref $_ ? $_->[0] : $_ }
 	@{ $self->{modules} }
     );
 }
 
-*test_without = \&modules;
-
 sub recommend {
     my ( $self ) = @_;
     my @missing = $self->check()
@@ -82,7 +78,7 @@ sub _module_stringify {
     my @arg = @_;
     my @rslt;
     foreach my $m ( @arg ) {
-	push @rslt, ARRAY_REF eq ref $m ? "@{ $m }" : $m;
+	push @rslt, 'ARRAY' eq ref $m ? "@{ $m }" : $m;
     }
     return @rslt;
 }
@@ -166,13 +162,6 @@ of missing modules in scalar context.
 This method just returns the names of the modules with which the object
 was initialized.
 
-=head2 test_without
-
- say 'Test without: ', join ', ', $rec->test_without();
-
-This method returns the names of the modules to test without. At this
-level of the hierarchy it is a synonym for L<modules()|/modules>.
-
 =head2 recommend
 
  my $msg;
@@ -187,9 +176,7 @@ modules are needed it returns nothing.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-satpass>,
-L<https://github.com/trwyant/perl-Astro-Coord-ECI/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -197,7 +184,7 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2025 by Thomas R. Wyant, III
+Copyright (C) 2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
