@@ -5,16 +5,14 @@ use 5.006002;
 use strict;
 use warnings;
 
-our $VERSION = '0.133_01';
+our $VERSION = '0.072';
 
-use Exporter qw{ import };
+use base qw{ Exporter };
 
 use Astro::Coord::ECI::TLE qw{ :constants };
 use Astro::Coord::ECI::Utils qw{ rad2deg };
 use Test::More 0.88;
 
-use constant CODE_REF	=> ref sub {};
-
 our @EXPORT_OK = qw{
     format_pass format_time
     magnitude
@@ -104,7 +102,7 @@ sub _format_optional {
     my ( $tplt, $hash, $key, $xfrm ) = @_;
     defined( my $val = $hash->{$key} )
 	or return '';
-    CODE_REF eq ref $xfrm
+    'CODE' eq ref $xfrm
 	and $val = $xfrm->( $val );
     return sprintf $tplt, $val;
 }
@@ -116,7 +114,7 @@ sub format_time {
 	$parts[4] + 1, @parts[ 3, 2, 1, 0 ];
 }
 
-sub magnitude {
+sub magnitude (@) {
     my ( $tle, @arg ) = @_;
     my ( $time, $want, $name ) = splice @arg, -3;
     my $got;
@@ -139,7 +137,7 @@ sub magnitude {
     }
 }
 
-sub tolerance {
+sub tolerance (@) {
     my ( $got, $want, $tolerance, $title, $fmtr ) = @_;
     $fmtr ||= sub { return $_[0] };
     $title =~ s{ (?<! [.] ) \z }{.}smx;
@@ -153,11 +151,11 @@ sub tolerance {
    Tolerance: $tolerance
 EOD
     chomp $title;
-    local $Test::Builder::Level = $Test::Builder::Level + 1;
-    return ok( $rslt, $title );
+    @_ = ( $rslt, $title );
+    goto &ok;
 }
 
-sub tolerance_frac {
+sub tolerance_frac (@) {
     my ( $got, $want, $tolerance, $title, $fmtr ) = @_;
     @_ = ( $got, $want, $tolerance * abs $want, $title, $fmtr );
     goto &tolerance;
@@ -182,7 +180,7 @@ sub tolerance_frac {
 	},
     );
 
-    sub velocity_sanity {
+    sub velocity_sanity ($$;$) {
 	my ( $method, $body, $sta ) = @_;
 	my $time = $body->universal();
 	my @rslt;
@@ -221,6 +219,7 @@ sub tolerance_frac {
 	    $grade = \&fail;
 	    $title .= <<"EOD";
 
+
            $dim( t + 1 ): $rslt[1][$inx]
                $dim( t ): $rslt[0][$inx]
           $dim dot ( t ): @{[ _dor( $rslt[0][$v_inx], '<undef>' ) ]}
@@ -257,6 +256,7 @@ reserves the right to change or revoke it without notice.
 This module is a repository for subroutines used in testing
 L<My::Module|My::Module>.
 
+
 =head1 SUBROUTINES
 
 The following public subroutines are exported by this module. None of
@@ -282,19 +282,6 @@ are also provided, on a line after the event.
 This subroutine converts a given Perl time into an ISO-8601-ish GMT
 time. It is used by C<format_pass()>.
 
-=head2 magnitude
-
- magnitude( $tle, $station, $time, $want, $name );
- magnitude( $tle, $time, $want, $name );
-
-This subroutine tests whether the magnitude of the satellite specified
-by C<$tle>, seen from the given C<$station> at the given C<$time>, has
-the value C<$want> to one decimal place. Argument C<$name> is the name
-of the test.
-
-If argument C<$station> is omitted, the C<station> attribute of the TLE
-is used.
-
 =head2 tolerance
 
  tolerance $got, $want, $tolerance, $title, $formatter
@@ -311,6 +298,8 @@ to code used to format the C<$got> and C<$want> values for display if
 the test fails. The formatter will be called with a single argument,
 which is the value to display.
 
+This subroutine is prototyped C<(@)>.
+
 =head2 tolerance_frac
 
  tolerance_frac $got, $want, $tolerance, $title
@@ -320,12 +309,12 @@ expressed as a fraction of the C<$want> value. It is actually just a
 stub that replaces the C<$tolerance> argument by
 C<< abs( $want * $tolerance ) >> and then does a C<goto &tolerance>.
 
+This subroutine is prototyped C<(@)>.
+
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-satpass>,
-L<https://github.com/trwyant/perl-Astro-Coord-ECI/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -333,7 +322,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2025 by Thomas R. Wyant, III
+Copyright (C) 2011-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
