@@ -50,7 +50,7 @@ package Astro::Coord::ECI::Sun;
 use strict;
 use warnings;
 
-our $VERSION = '0.071';
+our $VERSION = '0.072';
 
 use base qw{Astro::Coord::ECI};
 
@@ -217,7 +217,7 @@ C<correct_for_refraction()> method is actually called by those methods.
 =cut
 
 sub correct_for_refraction {
-    my ( $self, $elevation ) = @_;
+    my ( undef, $elevation ) = @_;	# Invocant unused
     return $elevation;
 }
 
