@@ -140,7 +140,7 @@ our @CARP_NOT = qw{
     Astro::Coord::ECI
 };
 
-our $VERSION = '0.071';
+our $VERSION = '0.072';
 
 use constant ERR_NOCURRENT => <<eod;
 Error - Can not call %s because there is no current member. Be
@@ -338,7 +338,8 @@ of the selected C<Astro::Coord::ECI::TLE> object.
 {
     my %override = (
 	tle	=> sub {
-	    my ( $self, $name ) = @_;
+##	    my ( $self, $name ) = @_;
+	    my ( $self ) = @_;	# Name unused
 	    my $output;
 	    foreach my $body ( $self->members() ) {
 		$output .= $body->get( 'tle' );
